@@ -194,7 +194,7 @@ use namespace::autoclean;
 use Class::Load;
 use Clone;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head2 data
 
@@ -297,7 +297,7 @@ has task_class => (
     isa      => 'Str',
     required => 1,
     default  => (
-        $^O !~ /^(dos|os2|MSWin32|NetWare)$/
+        $^O =~ /^(dos|os2|MSWin32|NetWare)$/
             ? 'Async::Simple::Task::ForkTmpFile'
             : 'Async::Simple::Task::Fork'
     ),
